@@ -25,7 +25,7 @@ from modelcluster.fields import ParentalKey
 from modelcluster.tags import ClusterTaggableManager
 from taggit.models import Tag, TaggedItemBase
 
-from webspace.cms.bakery.abstract import WagtailPageBakeryModel
+from webspace.bakery.abstract import WagtailPageBakeryModel
 from webspace.cms import constants
 from webspace.cms.amp.mixins import AmpMixin
 from webspace.cms.forms.abstract import FormMixin
