@@ -210,19 +210,13 @@ const CounterUp = {
         const number = Number(element.textContent) + 1;
 
         let counter = 0;
-        let delay = 1;
-        const x = number / 2;
-        let y = 0;
-
         function counterJs() {
-          y += 1;
-          delay = (x - y);
           element.innerHTML = counter.toString();
           counter += 1;
           if (counter < number) {
             setTimeout(() => {
               counterJs();
-            }, delay);
+            }, 50);
           }
         }
 
@@ -234,6 +228,19 @@ const CounterUp = {
   },
 };
 
+const Animation = {
+  init: () => {
+    const io = new IntersectionObserver(entries => entries.forEach((item) => {
+      const element = item.target;
+      if (item.isIntersecting) {
+        element.classList.add('start');
+        io.unobserve(element);
+      }
+    }));
+    document.querySelectorAll('.animation').forEach(element => io.observe(element));
+  },
+};
+
 export default {
   Image,
   Carousel,
@@ -244,4 +251,5 @@ export default {
   Collect,
   Accordion,
   CounterUp,
+  Animation,
 };
