@@ -1,15 +1,19 @@
 import logging
 import re
+from django import template
+
 from wagtail.embeds.embeds import get_embed
 from wagtail.embeds.exceptions import EmbedException
 
-from django import template
+from webspace.loader import get_model
 
 register = template.Library()
-
 logger = logging.getLogger('forms')
+IconSnippet = get_model('cms', 'IconSnippet')
 
 
+#  Icons
+
 @register.filter
 def ico(icon, theme):
     if icon:
@@ -18,11 +22,20 @@ def ico(icon, theme):
         return icon['light']
     return None
 
+
 @register.filter
 def ico_astro(icons, level):
     return icons['astro_level_%s' % level]
 
 
+@register.filter
+def ico_snippet(icon, theme):
+    doc = eval('icon.%s' % theme)
+    if doc:
+        return doc.file.url
+    return IconSnippet.DEFAULT_LINK
+
+
 @register.filter
 def ico_get(icons, key):
     try:
@@ -31,6 +44,8 @@ def ico_get(icons, key):
         return None
 
 
+#  Utils
+
 @register.filter
 def plur(value, arg='s'):
     if ',' not in arg:
@@ -76,7 +91,8 @@ def klass(ob):
 @register.filter
 def cached_form(form, request):
     if form:
-        if 'current_form_id' in request.session and request.session['current_form_id'] and form.id == request.session['current_form_id']:
+        if 'current_form_id' in request.session and request.session['current_form_id'] and form.id == request.session[
+            'current_form_id']:
             logger.debug("Take form cached")
             return form.get_form(request.POST, request.FILES, user=request.user)
         logger.debug("Take new form")
